/*
 * Copyright 2022 University of Liège
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef WDIRICHLET_H
#define WDIRICHLET_H

#include "heat.h"
#include "wGroup.h"
#include <vector>
#include <string>

using namespace tbox;

namespace heat
{

/**
 * @brief manage Dirichlet BC
 *
 * @todo gerer Dirichlet comme Boundary (avec une Fct en argument au lieu d'un scalaire)
 */

class HEAT_API Dirichlet : public Group
{
public:
    std::vector<Node *> nodes;
    double val; ///< value for a constant BC

    Dirichlet(std::shared_ptr<MshData> _msh, int no, double _val = 0.0);
    Dirichlet(std::shared_ptr<MshData> _msh, std::string const &name, double _val = 0.0);
    virtual ~Dirichlet() { std::cout << "~Dirichlet()\n"; }

    virtual void apply(std::vector<double> &rhs);

#ifndef SWIG
    virtual void write(std::ostream &out) const override;
#endif
};

} // namespace heat

#endif //WDIRICHLET_H
