/*
 * Copyright 2022 University of Liège
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef WEXTRACTOR_H
#define WEXTRACTOR_H

#include "heat.h"
#include "wExtract.h"

using namespace tbox;

namespace heat
{

/**
 * @brief an object able to extract scalar results from the model
 */

class HEAT_API Extractor : public fwk::Extract
{
    Solver &solver;
    Group &grp;

public:
    Extractor(Solver &_solver, Group &_grp);
    virtual ~Extractor() { std::cout << "~Extractor()\n"; }
    virtual std::vector<double> execute() override;
    std::vector<Node *> nodes; ///< faire une classe intermediaire group/dirichlet (nodegroup)

#ifndef SWIG
    virtual void write(std::ostream &out) const override;
#endif
};

} // namespace heat

#endif //WEXTRACTOR_H
