#!/usr/bin/env python3
# -*- coding: utf-8 -*-

# Copyright 2022 University of Liège
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# check the micro problem

import heat as h
import heat.utils as u
import tbox
import tbox.gmsh as gmsh
from fwk.testing import *

def main(TM, dTxM, dTyM):
    msh = gmsh.MeshLoader("micro.geo", __file__).execute()
    gmshWriter = tbox.GmshExport(msh)
    pbl = h.Problem(msh)

    pbl.add(h.Medium(msh, "Matrix",    tbox.Fct2C(1.,1.,0), 1.0))
    pbl.add(h.Medium(msh, "Inclusion", tbox.Fct2C(100.,100.,0), 1.0))
    p = h.Periodic(pbl, TM, dTxM, dTyM)
    pbl.add(p) 
      
    # solve problem
    solver = u.solve(pbl, gmshWriter)   
      
    # extract some results            
    tests = CTests()
    tests.add(CTest('mean flux X', p.qM[0], -2.278200, 1e-4))
    tests.add(CTest('mean flux Y', p.qM[1], -2.278258, 1e-4))
    tests.run()

if __name__ == "__main__":
    TM   = 1.0
    dTxM = 1.0
    dTyM = 1.0
    main(TM, dTxM, dTyM)
